@@ -88,12 +88,13 @@ const ChatView = new Lang.Class({
 
         this.widget.connect('style-updated',
                             Lang.bind(this, this._onStyleUpdated));
+        this._onStyleUpdated();
 
         this._room = room;
         this._state = { lastNick: null, lastTimestamp: 0 };
         this._active = false;
         this._toplevelFocus = false;
-        this._joinTime = GLib.DateTime.new_now_utc().to_unix();
+        this._joinTime = 0;
         this._maxNickChars = MAX_NICK_CHARS;
         this._hoveringLink = false;
         this._needsIndicator = true;
@@ -224,7 +225,6 @@ const ChatView = new Lang.Class({
     _createWidget: function() {
         this.widget = new Gtk.ScrolledWindow({ vexpand: true });
         this.widget.hscrollbar_policy = Gtk.PolicyType.NEVER;
-        this.widget.resize_mode = Gtk.ResizeMode.QUEUE;
 
         this._view = new TextView({ editable: false, cursor_visible: false,
                                     visible: true,
@@ -517,6 +517,7 @@ const ChatView = new Lang.Class({
         if (!this._channel)
             return;
 
+        this._joinTime = GLib.DateTime.new_now_utc().to_unix();
 
         let channelSignals = [
             { name: 'message-received',
