@@ -16,7 +16,7 @@ const MessageDialog = new Lang.Class({
     _init: function() {
         this._createWidget();
 
-        this._settings = new Gio.Settings({ schema: 'org.gnome.polari' });
+        this._settings = new Gio.Settings({ schema_id: 'org.gnome.polari' });
 
         this._accounts = {};
         AccountsMonitor.getDefault().dupAccounts().forEach(Lang.bind(this,
@@ -36,13 +36,21 @@ const MessageDialog = new Lang.Class({
 
         let factory = Tp.AccountManager.dup().get_factory();
         let lastUsed = factory.ensure_account(this._settings.get_string('last-used-account'), []);
-        let activeIndex = lastUsed ? names.indexOf(lastUsed.display_name) : 0;
+        let activeIndex = 0;
+        if (lastUsed)
+            activeIndex = Math.max(names.indexOf(lastUsed.display_name), 0);
         this._connectionCombo.set_active(activeIndex);
 
         this._updateCanConfirm();
         this._updateRecentList([]);
 
         this._nameEntry.grab_focus();
+
+        this.widget.connect('response', Lang.bind(this,
+            function(w, response) {
+                if (response == Gtk.ResponseType.OK)
+                    this._onMessageClicked();
+            }));
     },
 
     _createWidget: function() {
@@ -64,8 +72,6 @@ const MessageDialog = new Lang.Class({
         this._nameCompletion = builder.get_object('name_completion');
 
         this._messageButton = builder.get_object('message_button');
-        this._messageButton.connect('clicked',
-                                 Lang.bind(this, this._onMessageClicked));
         this._messageButton.sensitive = false;
 
         this._nameEntry = builder.get_object('name_entry');
@@ -172,7 +178,6 @@ const MessageDialog = new Lang.Class({
                                          [ account.get_object_path(),
                                            user,
                                            TP_CURRENT_TIME ]));
-        this.widget.response(Gtk.ResponseType.OK);
     },
 
     _updateCanConfirm: function() {
